@@ -8,7 +8,7 @@ use DBI;
 use DBD::SQLite;
 use JSON::XS;
 
-our $VERSION = '1.45'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -76,7 +76,6 @@ sub get {
     my $value;
 
     $self->{dbh} //= $self->_dbh;
-    warn $self->{dbh}, "\n";
 
     try {
         my $sth = $self->{dbh}->prepare_cached(q{
@@ -103,7 +102,6 @@ sub set {
     my $namespace = ( caller() )[0];
 
     $self->{dbh} //= $self->_dbh;
-    warn $self->{dbh}, "\n";
 
     try {
         $self->{dbh}->begin_work;
@@ -121,7 +119,6 @@ sub set {
         ) or die $self->{dbh}->errstr;
 
         $self->{dbh}->commit;
-        # $self->{dbh}->do('PRAGMA wal_checkpoint(FULL)') or die $self->{dbh}->errstr;
     }
     catch ($e) {
         $self->{dbh}->rollback;
@@ -145,7 +142,7 @@ Bot::IRC::Store::SQLite - Bot::IRC persistent data storage with SQLite
 
 =head1 VERSION
 
-version 1.45
+version 1.46
 
 =head1 SYNOPSIS
 
